@@ -1,5 +1,5 @@
-from helper import unittest, PillowTestCase, hopper
-from test_imageqt import PillowQtTestCase
+from .helper import PillowTestCase, hopper
+from .test_imageqt import PillowQtTestCase
 
 from PIL import ImageQt, Image
 
@@ -11,7 +11,7 @@ class TestFromQImage(PillowQtTestCase, PillowTestCase):
         Image.open('Tests/images/transparent.png'),
         Image.open('Tests/images/7x13.png'),
     ]
-    
+
     def roundtrip(self, expected):
         # PIL -> Qt
         intermediate = expected.toqimage()
@@ -42,9 +42,3 @@ class TestFromQImage(PillowQtTestCase, PillowTestCase):
     def test_sanity_p(self):
         for im in self.files_to_test:
             self.roundtrip(im.convert('P'))
-
-
-if __name__ == '__main__':
-    unittest.main()
-
-# End of file
